import tkinter as tk
from tkinter import simpledialog, scrolledtext, messagebox, filedialog, Toplevel
import json
import os
import subprocess
import webbrowser
from datetime import datetime
import google.generativeai as genai

CONFIG_FILE = "config.json"
SCRIPTS_DIR = "scripts"
os.makedirs(SCRIPTS_DIR, exist_ok=True)

# פונקציה לשמירת API Key וסטטיסטיקות
def save_config(data):
    with open(CONFIG_FILE, 'w') as f:
        json.dump(data, f)

# פונקציה לטעינת קונפיג
def load_config():
    if os.path.exists(CONFIG_FILE):
        with open(CONFIG_FILE) as f:
            return json.load(f)
    return {"api_key": None, "usage": 0}

# אתחול Gemini
def init_gemini():
    cfg = load_config()
    if not cfg.get("api_key"):
        raise Exception("API Key לא מוגדר.")
    genai.configure(api_key=cfg["api_key"])
    return genai.GenerativeModel("models/gemini-1.5-pro-latest")

# חילוץ קוד מתוך תגובת Gemini
def extract_code(text):
    if "```python" in text:
        return text.split("```python")[1].split("```", 1)[0].strip()
    return text.strip()

# בדיקת ספריות נדרשות לפי קוד
def detect_required_packages(code):
    try:
        model = init_gemini()
        prompt = (
            "Given the following Python code, return only the pip install commands that are required to run it.\n"
            + code
            + "\nIf no installation is needed, respond with 'no'. Do not explain anything."
        )
        response = model.generate_content(prompt)
        return extract_code(response.text)
    except Exception as e:
        return ""

# התקנת ספריות אם המשתמש מאשר
def maybe_install_packages(root, commands):
    if commands.strip().lower() == "no" or not commands.strip():
        return
    msg = "הסקריפט דורש התקנת ספריות:\n\n" + commands + "\n\nהאם לבצע את ההתקנה?"
    proceed = messagebox.askyesno("התקנת ספריות", msg)
    if proceed:
        try:
            result = subprocess.run(commands, shell=True, capture_output=True, text=True)
            messagebox.showinfo("תוצאה", f"סיום ההתקנה:\n{result.stdout}\n{result.stderr}")
        except Exception as e:
            messagebox.showerror("שגיאה בהתקנה", str(e))

# מחלקת GUI
class GeminiApp:
    def __init__(self, root):
        self.root = root
        self.root.title("Gemini - עוזר אישי")
        self.create_widgets()

    def create_widgets(self):
        top_frame = tk.Frame(self.root)
        top_frame.pack(fill='x', padx=10, pady=5)

        tk.Button(top_frame, text="🔐 הכנס API Key", command=self.set_api_key).grid(row=0, column=0, padx=5)
        tk.Button(top_frame, text="🌐 קבל API Key", command=lambda: webbrowser.open("https://aistudio.google.com/apikey")).grid(row=0, column=1, padx=5)
        tk.Button(top_frame, text="🧠 צור סקריפט", command=self.create_script).grid(row=0, column=2, padx=5)
        tk.Button(top_frame, text="✏️ ערוך סקריפט", command=self.edit_script).grid(row=0, column=3, padx=5)
        tk.Button(top_frame, text="🧪 נתח סקריפט", command=self.analyze_script).grid(row=0, column=4, padx=5)
        tk.Button(top_frame, text="▶️ הרץ", command=self.run_script).grid(row=0, column=5, padx=5)
        tk.Button(top_frame, text="📂 סקריפטים", command=self.list_scripts).grid(row=0, column=6, padx=5)

        prompt_frame = tk.Frame(self.root)
        prompt_frame.pack(fill='x', padx=10, pady=5)

        tk.Label(prompt_frame, text="שאל את Gemini (Shift+Enter לרדת שורה, Enter לשליחה):").pack(anchor='w')
        self.prompt_entry = tk.Text(prompt_frame, height=4, wrap='word')
        self.prompt_entry.pack(fill='x')
        self.prompt_entry.bind("<Return>", self.on_enter_pressed)

        self.output = scrolledtext.ScrolledText(self.root, height=20)
        self.output.pack(fill='both', expand=True, padx=10, pady=10)

    def on_enter_pressed(self, event):
        if event.state & 0x0001:
            return
        self.create_script()
        return "break"

    def set_api_key(self):
        win = Toplevel(self.root)
        win.title("API Key")
        tk.Label(win, text="הזן את ה-API Key שלך ל-Gemini:").pack(pady=5)
        entry = tk.Entry(win, width=50)
        entry.pack(pady=5)

        def paste_from_clipboard():
            try:
                entry.delete(0, tk.END)
                entry.insert(0, self.root.clipboard_get())
            except:
                pass

        btn_frame = tk.Frame(win)
        btn_frame.pack(pady=2)
        tk.Button(btn_frame, text="📋 הדבק מהלוח", command=paste_from_clipboard).pack(side='left', padx=5)
        tk.Button(btn_frame, text="✅ שמור והמשך", command=lambda: self.save_api_key(entry.get(), win)).pack(side='left', padx=5)

    def save_api_key(self, key, win):
        if key:
            cfg = load_config()
            cfg["api_key"] = key
            save_config(cfg)
            messagebox.showinfo("נשמר", "המפתח נשמר בהצלחה.")
            win.destroy()

    def update_usage(self):
        cfg = load_config()
        cfg["usage"] = cfg.get("usage", 0) + 1
        save_config(cfg)

    def create_script(self):
        # ... נשאר ללא שינוי ...
        pass

    def edit_script(self):
        # ... נשאר ללא שינוי ...
        pass

    def analyze_script(self):
        pass

    def run_script(self):
        # ... נשאר ללא שינוי ...
        pass

    def quick_edit(self, path):
        # ... נשאר ללא שינוי ...
        pass

    def list_scripts(self):
        files = os.listdir(SCRIPTS_DIR)
        py_files = [f for f in files if f.endswith(".py")]
        self.output.insert('end', f"[📁 סקריפטים בתיקייה '{SCRIPTS_DIR}']:\n" + "\n".join(py_files) + "\n\n")

if __name__ == '__main__':
    root = tk.Tk()
    app = GeminiApp(root)
    root.mainloop()
